import { createApi, fetchBaseQuery } from "@reduxjs/toolkit/query/react";
import { getConfigValue } from "@ijl/cli";

import { keycloak } from "../kc";
import { AccessCode, BaseResponse, Lesson, UserData } from "../model";

export const api = createApi({
  reducerPath: "auth",
  baseQuery: fetchBaseQuery({
    baseUrl: getConfigValue("journal.back.url"),
    fetchFn: async (input: RequestInfo | URL, init?: RequestInit | undefined) => {
      const response = await fetch(input, init);

      if (response.status === 403) {
        keycloak.login();
      }

      return response;
    },
    headers: {
      "Content-Type": "application/json;charset=utf-8",
    },
    prepareHeaders: (headers) => {
      headers.set('Authorization', `Bearer ${keycloak.token}`)
    }
  }),
  tagTypes: ['Lesson'],
  endpoints: (builder) => ({
    lessonList: builder.query<BaseResponse<Lesson[]>, void>({
      query: () => '/lesson/list',
      providesTags: ['Lesson']
    }),
    createLesson: builder.mutation<BaseResponse<Lesson>, Pick<Lesson, 'name'>>({
      query: ({ name }) => ({
        url: '/lesson',
        method: 'POST',
        body: {name },
      }),
      invalidatesTags: ['Lesson']
    }),
    lessonById: builder.query<BaseResponse<Lesson>, string>({
      query: (lessonId: string) => `/lesson/${lessonId}`
    }),
    createAccessCode: builder.query<BaseResponse<AccessCode>, { lessonId: string }>({
      query: ({ lessonId }) => ({
        url: '/lesson/access-code',
        method: 'POST',
        body: { lessonId },
      })
    }),
    getAccess: builder.query<BaseResponse<{ user: UserData, accessCode: AccessCode }>, { accessCode: string }>({
      query: ({ accessCode }) => ({
        url: `/lesson/access-code/${accessCode}`,
        method: 'GET',
      })
    })
  }),
});
