import React, { useEffect, useState, useRef } from 'react'
import { useParams } from 'react-router-dom'
import dayjs from 'dayjs'
import QRCode from 'qrcode'

import {
  MainWrapper,
  StartWrapper,
  QRCanvas,
  LessonItem,
  Lessonname,
} from './style'
import { api } from '../__data__/api/api'

export const Lesson = () => {
  const { lessonId } = useParams()
  const canvRef = useRef(null)
  const [lesson, setLesson] = useState(null)
  const { isFetching, isLoading, data: accessCode, error, isSuccess } =
    api.useCreateAccessCodeQuery(
      { lessonId },
      {
        pollingInterval: 3000,
        skipPollingIfUnfocused: true,
      },
    )
  useEffect(() => {
    if (!isFetching && isSuccess) {
      console.log(`${location.origin}/journal/u/${lessonId}/${accessCode.body._id}`)
      QRCode.toCanvas(
        canvRef.current,
        `${location.origin}/journal/u/${lessonId}/${accessCode.body._id}`,
        { width: 600 },
        function (error) {
          if (error) console.error(error)
          console.log('success!')
        },
      )
    }
  }, [isFetching, isSuccess])

  return (
    <MainWrapper>
      <StartWrapper>
        <h1>Тема занятия - {accessCode?.body?.lesson?.name}</h1>
        <span>{dayjs(accessCode?.body?.lesson?.date).format('DD MMMM YYYYг.')} Отмечено - {accessCode?.body?.lesson?.students?.length} человек</span>

        <QRCanvas ref={canvRef} />

        <ul style={{ paddingLeft: 0 }}>
          {accessCode?.body?.lesson?.students?.map((student, index) => (
            <LessonItem key={index}>
              <Lessonname>{student.name || student.preferred_username}</Lessonname>
            </LessonItem>
          ))}
        </ul>
      </StartWrapper>
    </MainWrapper>
  )
}
